@@ -1,6 +1,12 @@
 from typing import Dict, Tuple, List
 
 
+class ValueError(ValueError):
+    def __init__(self, message: str = ""):
+        self.message = f"Error in TransparentPath: {message}"
+        super().__init__(self.message)
+
+
 class MethodTranslator(object):
     """ """
 
